package com.sky.ioc.controller.life;

import com.sky.ioc.entity.params.IocDateParam;
import com.sky.ioc.service.canteen.RestaurantService;
import com.sky.ioc.tool.ReturnMsg;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

/**
 * @author LunCe
 * 智慧餐厅
 */

@Api(tags ="智享生活----智慧餐厅")
@Slf4j
@RestController
@RequestMapping("/restaurant")
public class RestaurantController {


    @Autowired
    private RestaurantService restaurantService;



    @ApiOperation("查询智慧生活中智慧餐厅的核心指标")
    @PostMapping("getCoreIndicators")
    public ReturnMsg  getCoreIndicators(@RequestBody IocDateParam iocDateParam){
//        iocDateParam   1.周，2.月，3.年
        return restaurantService.getCoreIndicators(iocDateParam);
    }

    @ApiOperation("查询智慧生活中智慧餐厅的用餐分析")
    @PostMapping("getMealAnalysis")
    public ReturnMsg  getMealAnalysis(@RequestBody IocDateParam iocDateParam){
        return restaurantService.getMealAnalysis(iocDateParam);
    }


    @ApiOperation("查询智慧生活中智慧餐厅的欢迎菜品")
    @PostMapping("getWelcomeDishes")
    public ReturnMsg getWelcomeDishes(@RequestBody IocDateParam iocDateParam){
        return restaurantService.getWelcomeDishes(iocDateParam);
    }


    @ApiOperation("查询智慧生活中智慧餐厅的消费分析")
    @PostMapping("getConsumptionAnalysis")
    public ReturnMsg  getConsumptionAnalysis(@RequestBody IocDateParam iocDateParam){
        return restaurantService.getConsumptionAnalysis(iocDateParam);
    }

    @ApiOperation("查询智慧生活中智慧餐厅的盈利分析")
    @PostMapping("getProfitAnalysis")
    public ReturnMsg  getProfitAnalysis(@RequestBody IocDateParam iocDateParam){
        return restaurantService.getProfitAnalysis(iocDateParam);
    }


    /**
     * TODO  查询智慧生活中智慧餐厅的支付分析
     * @Description
     * @Param iocDateParam
     * @Return java.lang.String
     * @Author LunCe
     * @date 2023/2/10 11:25
     */
    @ApiOperation("查询智慧生活中智慧餐厅的支付分析")
    @PostMapping("getPaymentAnalysis")
    public ReturnMsg  getPaymentAnalysis(@RequestBody IocDateParam iocDateParam){
        return restaurantService.getPaymentAnalysis(iocDateParam);
    }


    @ApiOperation("查询智慧生活中智慧餐厅的今日菜谱")
    @PostMapping("getTodayMenu")
    public ReturnMsg  getTodayMenu(){
        return restaurantService.getTodayMenu();
    }




}
